// Morphometric Minowski Numerical Analysis 
#include "binnedskymap.h"
#include "phasespace.h"

static std::string config_file = "minkmap.conf";
static std::string prefix_if = "input/";
static std::string prefix_of = "output/";
static std::string countratefilename = "no_filename";
static unsigned Nx = 100;
static unsigned Ny = Nx;
static double xmin = -1;
static double xmax = 1;
static double ymin = xmin;
static double ymax = xmax;
static double lambda = 5;
static double k_src = 0;
static std::string functionals = "APC";
static unsigned slide = 15;
static unsigned A_blackpix = 0;
static bool mbc = false;
static bool pix = false;
static bool verbose = true;
static unsigned seed = 17;
static unsigned seedsub = 23;

int main(int clc, char* clv[]){
  // Read in parameters
  intialize(clc, clv, config_file, prefix_if, prefix_of, countratefilename,
	    Nx, Ny, xmin, xmax, ymin, ymax, lambda, k_src, functionals, slide, A_blackpix, mbc, pix, verbose,
	    seed, seedsub);
  
  BinnedSkyMap skylab(Nx,Ny,xmin,xmax,ymin,ymax,prefix_if,prefix_of,seed,seedsub);
  skylab.add_bck_intensity(lambda);
  
  std::vector< double > mu_x_par(9,0);
  mu_x_par[0] = -0.7;
  mu_x_par[1] = 0;
  mu_x_par[2] = 0.7;
  mu_x_par[3] = -0.7;
  mu_x_par[4] = 0;
  mu_x_par[5] = 0.7;
  mu_x_par[6] = -0.7;
  mu_x_par[7] = 0;
  mu_x_par[8] = 0.7;
  std::vector< double > mu_y_par(9,0);
  mu_y_par[0] = 0.7;
  mu_y_par[1] = 0.7;
  mu_y_par[2] = 0.7;
  mu_y_par[3] = 0;
  mu_y_par[4] = 0;
  mu_y_par[5] = 0;
  mu_y_par[6] = -0.7;
  mu_y_par[7] = -0.7;
  mu_y_par[8] = -0.7;
  std::vector< double > sigma_xx_par(9,0.1);
  std::vector< double > sigma_yy_par(9,0.1);
  //sigma_xx_par[4] = 0.09;
  //sigma_yy_par[4] = 0.09;
  std::vector< double > phi_par(9,0);
  std::vector< double > ratio_par(9,0);
  
  double corner = 0.1425;
  double edge = 0.092;
  double center = 1-4*edge-4*corner;
  ratio_par[0] = corner;
  ratio_par[1] = edge;
  ratio_par[2] = corner;
  ratio_par[3] = edge;
  ratio_par[4] = center;
  ratio_par[5] = edge;
  ratio_par[6] = corner;
  ratio_par[7] = edge;
  ratio_par[8] = corner;
  Gaussian sources(mu_x_par,mu_y_par,sigma_xx_par,sigma_yy_par,phi_par,ratio_par,9);
  skylab.add_src_intensity(k_src, sources, true);
  
  int N_runs = 100;
  
  BinField<double> MeanMinkowskiSkyMap(Nx-slide+1,Ny-slide+1,0);
  for(int run=0;run<N_runs;run++){
    std::cout << "combined-global: run " << run << " of 0 ... " << N_runs-1 << std::endl;
    skylab.simulate_countrate();
    skylab.reduction_because_of_detector_acceptance();
    skylab.global_detector_correction(0.5, lambda);
    
    std::stringstream name;
    name << "singleMSM-combined-global-" << run;
    MeanMinkowskiSkyMap += skylab.Minkowski_sky_map_APC_pix_wbc(0.5*lambda, slide, verbose, true, true, name.str());
  }
  MeanMinkowskiSkyMap *= 1.0/N_runs;
  MeanMinkowskiSkyMap.out((xmax-xmin)/(Nx-slide+1), (ymax-ymin)/(Ny-slide+1),
			  skylab.call_xlow().subgrid((slide+1)/2-1,Nx-(slide+1)/2-1,(slide+1)/2-1,Nx-(slide+1)/2-1),
			  skylab.call_ylow().subgrid((slide+1)/2-1,Ny-(slide+1)/2-1,(slide+1)/2-1,Ny-(slide+1)/2-1),
			  "meanMSM-combined-global", prefix_of);
  
  return 0;
}
